
library(FactoMineR)
library(missMDA)

NC_coding <- read.csv("NWB_coding_Linguistics.txt", sep = "\t", header = TRUE)

# getting relevant languages only
# removing Shiwa as it doesn't fit our typology
NC_coding2 <- NC_coding[NC_coding$id != "shiw1234",]

# remove 'no data'
NC_coding4 <- NC_coding2[NC_coding2$DG_V_type != "5",]

#select only relevant columns
# leaving out: Other_Arg_Agr, AC_Other_Agr, Only_Animacy_NCF as these show no variety between yes/no
#decisions made on targets:
# gender: we leave out Sbj_Agr; Obj_Agr; Ind_Obj_Agr; Other_Arg_Agr
# AC, we leave out AC_on_V; AC_Ind_Obj_Agr,AC_Other_Ag and keep AC_Sbj_Agr & AC_Obj_Agr because unlike 
# for gender, there are some langs that have AC ob Obj but not Sbj

for(i in 1:75){
  NC_coding4[,i] <- as.factor(NC_coding4[,i])}

NC_coding4_sel <- NC_coding4[, c("Gender_on_Attr_Adj", "Gender_on_Dem", "Gender_on_Num", 
                                 "Gender_on_Quant", "Gender_on_Poss", "Gender_on_Wh_Words", 
                                 "Gender_on_V", "Gender_on_Pred_Adj", "Gender_on_Cop",  
                                 "Gender_on_Rel", "Gender_on_Ind_Pers_Pro", "Gender_on_Poss_Pro", 
                                 "Gender_on_Dem_Pro", "Gender_on_Refl_Pro", "Gender_on_Other", 
                                 "AC_on_Attr_Adj", "AC_on_Dem", "AC_on_Num", "AC_on_Quant", 
                                 "AC_on_Poss", "AC_on_Wh_words",  "AC_Sbj_Agr", "AC_Obj_Agr", 
                                 "AC_on_Pred_Adj", "AC_on_Cop", "AC_on_Rel", "AC_on_Pers_Pro", 
                                 "AC_on_Poss_Pro", "AC_on_Dem_Pro", "AC_on_Refl_Pro", "AC_on_Other", 
                                 "AC_Obl_NP", "AC_Obl_Everywhere", "Only_Number_Agr", "Only_Number_NCF", 
                                 "Animacy_Number_NFC", "Extra_NCF_Animacy", "Extra_NCF_Number", 
                                 "Extra_NCF_Animacy.Number")]

NC_coding4_sel[NC_coding4_sel == "?"] <- NA
NC_coding4_sel[NC_coding4_sel == "not applicable"] <- NA

#checking no of levels
cats <- apply(NC_coding4_sel, 2, function(x) nlevels(as.factor(x)))
cats # should be 2 for all, otherwise NA is counted as a category which leads to wrong results

#MCA
tab.disj.comp <- imputeMCA(NC_coding4_sel, ncp = 1) 
mca1 <- MCA(NC_coding4_sel, tab.disj = tab.disj.comp$tab.disj, graph = F)
summary(mca1)

NC_coding4$Dim1 <- mca1$ind$coord[,1]
NC_coding4$Dim2 <- mca1$ind$coord[,2]

write.table(mca1$ind$coord, file = "MCA_results.txt", sep = "\t") 

#plotting
pdf(file = "MCA_plot.pdf", width = 6, height = 6)
par(mfrow=c(1,1))
plot(NC_coding4$Dim1, NC_coding4$Dim2, ylab = "MCA Dimension 2", xlab = "MCA Dimension 1", 
     col=c('black', 'blue', 'darkorange','green')[as.numeric(NC_coding4$DG_V_type)])
legend("topright", legend = c("syntactic agreement only", 
                             "syn. and ani.-based agreement", 
                             "animacy-based agreeemtn only", "no gender"), 
       fill = c('black', 'blue', 'darkorange','green'), cex = 0.70)
dev.off()
