# inspiration for the big target plot:
# https://stackoverflow.com/questions/48531257/ggplot-geom-point-how-to-set-font-of-custom-plotting-symbols


library(reshape2)
library(Cairo)
library(ggplot2)

NC_coding <- read.csv("NWB_coding_Linguistics.txt", sep = "\t", header = TRUE, na.strings = c("?", "not applicable"))

# getting relevant languages only
# removing Shiwa as it doesn't fit our typology
NC_coding2 <- NC_coding[NC_coding$id != "shiw1234",]

# remove 'no data' and languages without animacy-based agreement
NC_coding4 <- NC_coding2[NC_coding2$DG_V_type != 5,]
NC_coding5 <- NC_coding4[NC_coding4$DG_V_type != 1,]
NC_coding5 <- NC_coding5[NC_coding5$DG_V_type != 4,]

# making sure we have a dataframe:
for(i in 1:75){
  NC_coding5[,i] <- as.factor(NC_coding5[,i])}

# select & reorder column order
NC_coding5_all <- NC_coding5[, c("name","Gender_on_V", "Gender_on_Ind_Pers_Pro", "Gender_on_Poss_Pro",  "Gender_on_Wh_Words", "Gender_on_Attr_Adj", "Gender_on_Dem", "Gender_on_Num", "Gender_on_Poss", "Gender_on_Quant",  "Gender_on_Cop", "Gender_on_Pred_Adj",  "Gender_on_Rel","Gender_on_Dem_Pro", "Gender_on_Refl_Pro", "Gender_on_Other",  "AC_on_V",  "AC_on_Pers_Pro", "AC_on_Poss_Pro", "AC_on_Wh_words","AC_on_Attr_Adj", "AC_on_Dem", "AC_on_Num", "AC_on_Poss", "AC_on_Quant",  "AC_on_Cop", "AC_on_Pred_Adj", "AC_on_Rel",  "AC_on_Dem_Pro", "AC_on_Refl_Pro", "AC_on_Other")]
NC_coding5_all <-droplevels(NC_coding5_all)

#adjust order of languages, which is based on levels in ggplot
NC_coding5_all$name <- factor(NC_coding5_all$name, levels = c("Bodo (Central African Republic)", "Kari (Democratic Republic of Congo)", "Mbati", "Pande", "Amba (Uganda)","Bila", "Kako", "Nzadi",  "Beeke", "Bera",   "Lingala (Bokamba)",  "Ngelima",  "Lika",  "Boloki","Ding",  "Lefa",  "Ngando (Democratic Republic of Congo)", "Ntomba", "Nyali", "Sengele", "Sira",  "Tembo (Motembo)", "Tuki", "Mongo (Atlantic-Congo)", "Bangi",   "San Salvador Kongo", "Ndumu", "Ngombe (Democratic Republic of Congo)",  "Zamba", "Suku","Bolia", "Bomboma", "Bongili", "Bwela", "Kaamba", "Kele (Democratic Republic of Congo)", "Laari", "Lengola", "Libinza", "Ligenza", "Moi (Congo)",   "Sakata", "Songomeno",  "Yaka (Democratic Republic of Congo)", "Mpiemo",  "Pagibete", "Bwa","Vili", "Ukhwejo","Suundi", "Kimbundu"))

NC_coding5_gen <- NC_coding5_all[, c("name","Gender_on_V", "Gender_on_Ind_Pers_Pro",  "Gender_on_Attr_Adj", 
                                     "Gender_on_Poss_Pro",  "Gender_on_Dem", "Gender_on_Wh_Words", "Gender_on_Cop", 
                                     "Gender_on_Num", "Gender_on_Poss", "Gender_on_Quant",   "Gender_on_Pred_Adj", 
                                     "Gender_on_Dem_Pro", "Gender_on_Rel", "Gender_on_Other", "Gender_on_Refl_Pro")]
NC_coding5_AC <- NC_coding5_all[, c("name","AC_on_V",  "AC_on_Pers_Pro", "AC_on_Attr_Adj", 
                                    "AC_on_Poss_Pro", "AC_on_Dem", "AC_on_Wh_words", "AC_on_Cop", 
                                    "AC_on_Num", "AC_on_Poss", "AC_on_Quant",  "AC_on_Pred_Adj", 
                                    "AC_on_Dem_Pro", "AC_on_Rel", "AC_on_Other", "AC_on_Refl_Pro")]

NC_coding5_gen[NC_coding5_gen == "?"] <- "NA"
NC_coding5_gen[NC_coding5_gen == "not applicable"] <- "NA"

NC_coding5_AC[NC_coding5_AC == "?"] <- "NA"
NC_coding5_AC[NC_coding5_AC == "not applicable"] <- "NA"

#reordering and renaming
colnames(NC_coding5_gen) <- c("name","Verb","Ind_Pers_Pro", "Attr_Adj", "Poss_Pro", "Dem", "Wh_Words", "Cop",
                              "Num","Poss","Quant", "Pred_Adj", "Dem_Pro", "Rel", "Other", "Refl_Pro")
colnames(NC_coding5_AC) <- c("name","Verb","Ind_Pers_Pro", "Attr_Adj", "Poss_Pro", "Dem", "Wh_Words", "Cop",
                             "Num","Poss","Quant", "Pred_Adj", "Dem_Pro", "Rel", "Other", "Refl_Pro")

colnames(NC_coding5_gen) <- c("name","V","PeP", "AA", "PoP", "D","Wh", "C", 
                              "N","Poss","Q", "PA","DP","R","O", "RP")
colnames(NC_coding5_AC) <- c("name","V","PeP", "AA", "PoP", "D","Wh", "C", 
                             "N","Poss","Q", "PA","DP","R","O", "RP")

#testing no of levels
cats <- apply(NC_coding5_gen, 2, function(x) nlevels(as.factor(x)))
cats # should be 3 for all
cats <- apply(NC_coding5_AC, 2, function(x) nlevels(as.factor(x)))
cats # should be 3 for all

#melt
NC_coding5_gen_melted <- melt(NC_coding5_gen, id = "name")
NC_coding5_AC_melted <- melt(NC_coding5_AC, id = "name")

NC_coding5_gen_melted$group <- "syntactic"
NC_coding5_AC_melted$group <- "animacy-based"

NC_coding5_melt_merged <- rbind(NC_coding5_gen_melted, NC_coding5_AC_melted)

#plot
P <-  ggplot(NC_coding5_melt_merged, aes(x = variable, y = name, color = value, shape = group)) +
  geom_point(size = 14) +
  scale_shape_manual(values=c("\u25E2","\u25E4")) +
  scale_color_manual(values=c("gray94", "yellow", "gray13")) +
  theme_minimal() +
  theme(panel.grid = element_blank() +
  theme(axis.text.x = element_text(angle = 90, vjust = 1, hjust=0)))

#save
cairo_pdf("big_target_plot.pdf", family="Arial Unicode MS", 8, 14)
P
dev.off()
