

NC_coding <- read.csv("NWB_coding_Linguistics.txt", sep = "\t", header = TRUE, stringsAsFactors=FALSE)

# getting relevant languages only
# removing Shiwa as it doesn't fit our typology
NC_coding2 <- NC_coding[NC_coding$id != "shiw1234",]

# remove 'no data'
NC_coding3 <- NC_coding2[NC_coding2$DG_V_type != "5",]

NC_s2 <- NC_coding3
NC_s2 <- droplevels(NC_s2)

# create a matrix with the tables on all the questions 
grep("Gender_on_Attr_Adj", colnames(NC_s2)) #29
grep("AC_on_Other", colnames(NC_s2)) #66

t_storage <- matrix(data = NA, nrow = 38, ncol = 10)
rownames(t_storage) <- colnames(NC_s2)[29:66]

for(i in 29:66){
  t <- table(NC_s2[,i])
  l <- length(names(t))
  for(j in 1:l){
    t_storage[i-28,j] <- names(t)[j]
    t_storage[i-28,j+5] <- t[j]
  }
}

conv <- t(t_storage)

# We keep only Gender_on_Verb for syntactic gender, and AC_Sbj_Agr and AC_Obj_Agr. 
# for symmetry in the plots, we take AC_on_Verb, which captures both marking of Sbj & Obj.
conv2 <- conv[,-(10:13)]
conv2 <- conv2[,-(25:28)]

conv2[8,] <- 178 - (as.numeric(conv2[6,]) + as.numeric(conv2[7,]))

#turn around 'yes' and 'no'
conv2[5,] <- conv2[6,]
conv2[6,] <- conv2[7,]
conv2[7,] <- conv2[5,]

# test plot
barplot(conv2[6:8,], col = c("gray", "yellow", "magenta"), las=2)
legend("bottomleft", legend = c("?","no","yes"), fill = c("gray", "yellow", "magenta"))

# sorting them
new_order <- c("Gender_on_Dem", "Gender_on_Poss", "Gender_on_Num", "Gender_on_Poss_Pro", "Gender_on_V", "Gender_on_Attr_Adj", "Gender_on_Quant", "Gender_on_Ind_Pers_Pro", "Gender_on_Rel", "Gender_on_Wh_Words", "Gender_on_Dem_Pro", "Gender_on_Cop", "Gender_on_Pred_Adj", "Gender_on_Other", "Gender_on_Refl_Pro", 
              "AC_on_V",  "AC_on_Pers_Pro","AC_on_Wh_words",  "AC_on_Attr_Adj", "AC_on_Dem", "AC_on_Poss_Pro", "AC_on_Cop", "AC_on_Num", "AC_on_Poss", "AC_on_Quant",   "AC_on_Pred_Adj",  "AC_on_Dem_Pro", "AC_on_Rel",  "AC_on_Other", "AC_on_Refl_Pro")

# checking
ncol(conv2)
colnames(conv2)
length(new_order)

# changing the order of targets
conv3 <- as.matrix(conv2)
conv3[1,] <- c("Attr Adj","Dem","Num","Quant","Gen","Q Words","Verb","Pred Adj","Cop","Rel","Ind Pers Pro","Poss Pro","Dem Pro","Refl Pro","Other","Attr Adj","Dem","Num","Quant","Gen","Q Words","Pred Adj","Cop","Verb","Rel","Ind Pers Pro","Poss Pro","Dem Pro","Refl Pro","Other")
conv4 <- conv3[,new_order]

#reverse
conv5 <- conv4[,ncol(conv4):1]

#reverse order of yes/no/?
conv5[2,] <- conv5[8,]
conv5[3,] <- conv5[7,]
conv5[4,] <- conv5[6,]

col1 = c("gray", "yellow", "cornflowerblue")
col2 = c("black", "white", "gray")

#preparation for plot
par("mar")
par(mar=c(3,6,3,3)) #decrease margins
par(mfrow = c(1,2))

barplot(conv5[rev(2:4),16:30], col = col2, space = 0.3, las=2, xlim = c(0,180), horiz = T, names.arg = conv5[1,16:30], main = "Syntactic agreement")
barplot(conv5[rev(2:4),1:15], col = col2, space = 0.3, las=2, xlim = c(0,180), horiz = T, names.arg = conv5[1,1:15], main = "Animacy-based agreement")
legend("bottomleft", legend = c("present","absent","unknown"), fill = col2)

# for some reason Cairo doesn't work with the required plot margins, so save from the plot window
# the legend is manually shifted to the right position. 

