

library(ape)
library(phytools) #fitPagel

NC_coding <- read.csv("NWB_coding_Linguistics.txt", sep = "\t", header = TRUE)

Bantu_tree <- read.nexus("Koile_et_al_tree.nex")

# getting relevant languages only
# removing Shiwa as it doesn't fit our typology
NC_coding2 <- NC_coding[NC_coding$id != "shiw1234",]

# remove 'no data'
NC_coding4 <- NC_coding2[NC_coding2$DG_V_type != "5",]

# remove empty rows, without a tree name

NC_coding4_for_tree <- NC_coding4[NC_coding4$Koile_et_al_tree_name != "",] # 

# remove these which don't have a presence in the tree
NC_coding4_for_tree <- NC_coding4_for_tree[NC_coding4_for_tree$Koile_et_al_tree_name != "Glotto_Bafoto",]
NC_coding4_for_tree <- NC_coding4_for_tree[NC_coding4_for_tree$Koile_et_al_tree_name != "Glotto_Beeke",]
NC_coding4_for_tree <- NC_coding4_for_tree[NC_coding4_for_tree$Koile_et_al_tree_name != "D20B_Vamba_1919",]

# prune  tree:

drop_tips <- NC_coding4_for_tree$Koile_et_al_tree_name
all_tips <- Bantu_tree$tip.label
to_drop <- setdiff(all_tips, drop_tips)

Bantu_tree2 <- drop.tip(Bantu_tree, to_drop)
Bantu_tree2

#checking tree labels to languages present
setdiff(NC_coding4_for_tree$Koile_et_al_tree_name, Bantu_tree2$tip.label)
setdiff(Bantu_tree2$tip.label, NC_coding4_for_tree$Koile_et_al_tree_name)

nrow(NC_coding4_for_tree)
tree_tips <- Bantu_tree2$tip.label
str(tree_tips)

NC_coding5 <- NC_coding4_for_tree

# since "gender on other" is (almost entirely) invariant, we remove it
# table(NC_coding5$Other_Arg_Agr)
# We keep only Gender_on_Verb for traditional gender, and AC_Sbj_Agr and AC_Obj_Agr. 
# for symmetry in the plots, we take AC_on_Verb, which captures both marking of Sbj & Obj.

NC_coding5$Other_Arg_Agr <- NULL
NC_coding5$Sbj_Agr <- NULL
NC_coding5$Obj_Agr <- NULL
NC_coding5$Ind_Obj_Agr <- NULL

NC_coding5$AC_Sbj_Agr	<- NULL
NC_coding5$AC_Obj_Agr	<- NULL
NC_coding5$AC_Ind_Obj_Agr	<- NULL
NC_coding5$AC_Other_Agr <- NULL

#recode yes/no into 1/0 and drop the "" level that is there because of as of yet unanswered questions in the questionnaire

#first, have a look at variable numbers
grep("AC_on_Attr_Adj", colnames(NC_coding5)) #44
grep("AC_on_Other", colnames(NC_coding5)) #58

NC_coding6 <- NC_coding5[,44:58]

for(i in 1:15){
  NC_coding6[,i] <- as.factor(NC_coding6[,i])
  levels(NC_coding6[,i])[levels(NC_coding6[,i])=="?"] <- NA
  levels(NC_coding6[,i])[levels(NC_coding6[,i])=="yes"] <- 1
  levels(NC_coding6[,i])[levels(NC_coding6[,i])=="no"] <- 0
  levels(NC_coding6[,i])[levels(NC_coding6[,i])=="not applicable"] <- 0
  NC_coding6[,i] <- droplevels(NC_coding6[,i])
}

NC_coding6 <- cbind(NC_coding6, NC_coding5$Koile_et_al_tree_name)

matrix_res <- matrix(NA, nrow = 15, ncol = 15)
rownames(matrix_res) <- colnames(NC_coding5[,44:58])
colnames(matrix_res) <- colnames(NC_coding5[,44:58])

# playing around with names
names1 <- c("Demonstrative", "Poss Pro","Rel Clause","Attr Adj","Numeral","Quantifier","Genitive","Q Word","Pred Adj","Copula","Verb","Ind Pers Pro","Dem Pro","Refl Pro","Other")

rownames(matrix_res) <- names1
colnames(matrix_res) <- names1

#reorder
NC_coding6 <- NC_coding6[c("AC_on_Dem","AC_on_Poss_Pro", "AC_on_Rel","AC_on_Attr_Adj","AC_on_Num","AC_on_Quant","AC_on_Poss","AC_on_Wh_words","AC_on_Pred_Adj","AC_on_Cop","AC_on_V","AC_on_Pers_Pro","AC_on_Dem_Pro","AC_on_Refl_Pro","AC_on_Other","NC_coding5$Koile_et_al_tree_name")]

#check
colnames(NC_coding6)


# PHYTOOLS FUNCTION FITPAGEL - by Liam Revell
# http://blog.phytools.org/2014/12/r-function-for-pagels-1994-correlation.html
# unfortunately doesn't like NA, see e-mail from Revell 09-11-2017, so remove these

# one individual analysis:
NC_coding7 <- droplevels(NC_coding6)

feature1 <- NC_coding7[,1]
names(feature1) <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`

feature2 <- NC_coding7[,5]
names(feature2) <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`

feature1_missing <- which(is.na(feature1))
feature2_missing <- which(is.na(feature2))
index <- union(feature1_missing,feature2_missing)
index_sorted <- sort(index)
to_drop <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`[index_sorted]
to_drop2 <- as.vector(to_drop)
feature1 <- feature1[-index_sorted]
feature2 <- feature2[-index_sorted]
Bantu_tree3 <- drop.tip(Bantu_tree2, to_drop2)
length(feature1)
length(feature2)
fit <- fitPagel(Bantu_tree3, x = feature1, y = feature2, model = "SYM")
fit

# runs for each column:

for(i in 1:15){

  feature1 <- NC_coding7[,1]
  names(feature1) <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`
  
  feature2 <- NC_coding7[,i]
  names(feature2) <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`
  
  feature1_missing <- which(is.na(feature1))
  feature2_missing <- which(is.na(feature2))
  index <- union(feature1_missing,feature2_missing)
  index_sorted <- sort(index)
  to_drop <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`[index_sorted]
  to_drop2 <- as.vector(to_drop)
  feature1 <- feature1[-index_sorted]
  feature2 <- feature2[-index_sorted]
  Bantu_tree3 <- drop.tip(Bantu_tree2, to_drop2)

fit <- fitPagel(Bantu_tree3, x = feature1, y = feature2, model = "SYM")
matrix_res[1,i] <- fit$P
}

for(i in 1:15){
  
  feature1 <- NC_coding7[,2]
  names(feature1) <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`
  
  feature2 <- NC_coding7[,i]
  names(feature2) <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`
  
  feature1_missing <- which(is.na(feature1))
  feature2_missing <- which(is.na(feature2))
  index <- union(feature1_missing,feature2_missing)
  index_sorted <- sort(index)
  to_drop <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`[index_sorted]
  to_drop2 <- as.vector(to_drop)
  feature1 <- feature1[-index_sorted]
  feature2 <- feature2[-index_sorted]
  Bantu_tree3 <- drop.tip(Bantu_tree2, to_drop2)
  
  fit <- fitPagel(Bantu_tree3, x = feature1, y = feature2, model = "SYM")
  matrix_res[2,i] <- fit$P
}

for(i in 1:15){
  
  feature1 <- NC_coding7[,3]
  names(feature1) <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`
  
  feature2 <- NC_coding7[,i]
  names(feature2) <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`
  
  feature1_missing <- which(is.na(feature1))
  feature2_missing <- which(is.na(feature2))
  index <- union(feature1_missing,feature2_missing)
  index_sorted <- sort(index)
  to_drop <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`[index_sorted]
  to_drop2 <- as.vector(to_drop)
  feature1 <- feature1[-index_sorted]
  feature2 <- feature2[-index_sorted]
  Bantu_tree3 <- drop.tip(Bantu_tree2, to_drop2)
  
  fit <- fitPagel(Bantu_tree3, x = feature1, y = feature2, model = "SYM")
  matrix_res[3,i] <- fit$P
}

for(i in 1:15){
  
  feature1 <- NC_coding7[,4]
  names(feature1) <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`
  
  feature2 <- NC_coding7[,i]
  names(feature2) <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`
  
  feature1_missing <- which(is.na(feature1))
  feature2_missing <- which(is.na(feature2))
  index <- union(feature1_missing,feature2_missing)
  index_sorted <- sort(index)
  to_drop <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`[index_sorted]
  to_drop2 <- as.vector(to_drop)
  feature1 <- feature1[-index_sorted]
  feature2 <- feature2[-index_sorted]
  Bantu_tree3 <- drop.tip(Bantu_tree2, to_drop2)
  
  fit <- fitPagel(Bantu_tree3, x = feature1, y = feature2, model = "SYM")
  matrix_res[4,i] <- fit$P
}

for(i in 1:15){
  
  feature1 <- NC_coding7[,5]
  names(feature1) <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`
  
  feature2 <- NC_coding7[,i]
  names(feature2) <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`
  
  feature1_missing <- which(is.na(feature1))
  feature2_missing <- which(is.na(feature2))
  index <- union(feature1_missing,feature2_missing)
  index_sorted <- sort(index)
  to_drop <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`[index_sorted]
  to_drop2 <- as.vector(to_drop)
  feature1 <- feature1[-index_sorted]
  feature2 <- feature2[-index_sorted]
  Bantu_tree3 <- drop.tip(Bantu_tree2, to_drop2)
  
  fit <- fitPagel(Bantu_tree3, x = feature1, y = feature2, model = "SYM")
  matrix_res[5,i] <- fit$P
}

for(i in 1:15){
  
  feature1 <- NC_coding7[,6]
  names(feature1) <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`
  
  feature2 <- NC_coding7[,i]
  names(feature2) <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`
  
  feature1_missing <- which(is.na(feature1))
  feature2_missing <- which(is.na(feature2))
  index <- union(feature1_missing,feature2_missing)
  index_sorted <- sort(index)
  to_drop <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`[index_sorted]
  to_drop2 <- as.vector(to_drop)
  feature1 <- feature1[-index_sorted]
  feature2 <- feature2[-index_sorted]
  Bantu_tree3 <- drop.tip(Bantu_tree2, to_drop2)
  
  fit <- fitPagel(Bantu_tree3, x = feature1, y = feature2, model = "SYM")
  matrix_res[6,i] <- fit$P
}
for(i in 1:15){
  
  feature1 <- NC_coding7[,7]
  names(feature1) <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`
  
  feature2 <- NC_coding7[,i]
  names(feature2) <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`
  
  feature1_missing <- which(is.na(feature1))
  feature2_missing <- which(is.na(feature2))
  index <- union(feature1_missing,feature2_missing)
  index_sorted <- sort(index)
  to_drop <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`[index_sorted]
  to_drop2 <- as.vector(to_drop)
  feature1 <- feature1[-index_sorted]
  feature2 <- feature2[-index_sorted]
  Bantu_tree3 <- drop.tip(Bantu_tree2, to_drop2)
  
  fit <- fitPagel(Bantu_tree3, x = feature1, y = feature2, model = "SYM")
  matrix_res[7,i] <- fit$P
}

for(i in 1:15){
  
  feature1 <- NC_coding7[,8]
  names(feature1) <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`
  
  feature2 <- NC_coding7[,i]
  names(feature2) <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`
  
  feature1_missing <- which(is.na(feature1))
  feature2_missing <- which(is.na(feature2))
  index <- union(feature1_missing,feature2_missing)
  index_sorted <- sort(index)
  to_drop <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`[index_sorted]
  to_drop2 <- as.vector(to_drop)
  feature1 <- feature1[-index_sorted]
  feature2 <- feature2[-index_sorted]
  Bantu_tree3 <- drop.tip(Bantu_tree2, to_drop2)
  
  fit <- fitPagel(Bantu_tree3, x = feature1, y = feature2, model = "SYM")
  matrix_res[8,i] <- fit$P
}

for(i in 1:15){
  
  feature1 <- NC_coding7[,9]
  names(feature1) <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`
  
  feature2 <- NC_coding7[,i]
  names(feature2) <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`
  
  feature1_missing <- which(is.na(feature1))
  feature2_missing <- which(is.na(feature2))
  index <- union(feature1_missing,feature2_missing)
  index_sorted <- sort(index)
  to_drop <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`[index_sorted]
  to_drop2 <- as.vector(to_drop)
  feature1 <- feature1[-index_sorted]
  feature2 <- feature2[-index_sorted]
  Bantu_tree3 <- drop.tip(Bantu_tree2, to_drop2)
  
  fit <- fitPagel(Bantu_tree3, x = feature1, y = feature2, model = "SYM")
  matrix_res[9,i] <- fit$P
}

for(i in 1:15){
  
  feature1 <- NC_coding7[,10]
  names(feature1) <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`
  
  feature2 <- NC_coding7[,i]
  names(feature2) <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`
  
  feature1_missing <- which(is.na(feature1))
  feature2_missing <- which(is.na(feature2))
  index <- union(feature1_missing,feature2_missing)
  index_sorted <- sort(index)
  to_drop <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`[index_sorted]
  to_drop2 <- as.vector(to_drop)
  feature1 <- feature1[-index_sorted]
  feature2 <- feature2[-index_sorted]
  Bantu_tree3 <- drop.tip(Bantu_tree2, to_drop2)
  
  fit <- fitPagel(Bantu_tree3, x = feature1, y = feature2, model = "SYM")
  matrix_res[10,i] <- fit$P
}

for(i in 1:15){
  
  feature1 <- NC_coding7[,11]
  names(feature1) <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`
  
  feature2 <- NC_coding7[,i]
  names(feature2) <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`
  
  feature1_missing <- which(is.na(feature1))
  feature2_missing <- which(is.na(feature2))
  index <- union(feature1_missing,feature2_missing)
  index_sorted <- sort(index)
  to_drop <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`[index_sorted]
  to_drop2 <- as.vector(to_drop)
  feature1 <- feature1[-index_sorted]
  feature2 <- feature2[-index_sorted]
  Bantu_tree3 <- drop.tip(Bantu_tree2, to_drop2)
  
  fit <- fitPagel(Bantu_tree3, x = feature1, y = feature2, model = "SYM")
  matrix_res[11,i] <- fit$P
}

for(i in 1:15){
  
  feature1 <- NC_coding7[,12]
  names(feature1) <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`
  
  feature2 <- NC_coding7[,i]
  names(feature2) <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`
  
  feature1_missing <- which(is.na(feature1))
  feature2_missing <- which(is.na(feature2))
  index <- union(feature1_missing,feature2_missing)
  index_sorted <- sort(index)
  to_drop <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`[index_sorted]
  to_drop2 <- as.vector(to_drop)
  feature1 <- feature1[-index_sorted]
  feature2 <- feature2[-index_sorted]
  Bantu_tree3 <- drop.tip(Bantu_tree2, to_drop2)
  
  fit <- fitPagel(Bantu_tree3, x = feature1, y = feature2, model = "SYM")
  matrix_res[12,i] <- fit$P
}

for(i in 1:15){
  
  feature1 <- NC_coding7[,13]
  names(feature1) <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`
  
  feature2 <- NC_coding7[,i]
  names(feature2) <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`
  
  feature1_missing <- which(is.na(feature1))
  feature2_missing <- which(is.na(feature2))
  index <- union(feature1_missing,feature2_missing)
  index_sorted <- sort(index)
  to_drop <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`[index_sorted]
  to_drop2 <- as.vector(to_drop)
  feature1 <- feature1[-index_sorted]
  feature2 <- feature2[-index_sorted]
  Bantu_tree3 <- drop.tip(Bantu_tree2, to_drop2)
  
  fit <- fitPagel(Bantu_tree3, x = feature1, y = feature2, model = "SYM")
  matrix_res[13,i] <- fit$P
}

for(i in 1:15){
  
  feature1 <- NC_coding7[,14]
  names(feature1) <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`
  
  feature2 <- NC_coding7[,i]
  names(feature2) <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`
  
  feature1_missing <- which(is.na(feature1))
  feature2_missing <- which(is.na(feature2))
  index <- union(feature1_missing,feature2_missing)
  index_sorted <- sort(index)
  to_drop <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`[index_sorted]
  to_drop2 <- as.vector(to_drop)
  feature1 <- feature1[-index_sorted]
  feature2 <- feature2[-index_sorted]
  Bantu_tree3 <- drop.tip(Bantu_tree2, to_drop2)
  
  fit <- fitPagel(Bantu_tree3, x = feature1, y = feature2, model = "SYM")
  matrix_res[14,i] <- fit$P
}

for(i in 1:15){
  
  feature1 <- NC_coding7[,15]
  names(feature1) <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`
  
  feature2 <- NC_coding7[,i]
  names(feature2) <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`
  
  feature1_missing <- which(is.na(feature1))
  feature2_missing <- which(is.na(feature2))
  index <- union(feature1_missing,feature2_missing)
  index_sorted <- sort(index)
  to_drop <- NC_coding7$`NC_coding5$Koile_et_al_tree_name`[index_sorted]
  to_drop2 <- as.vector(to_drop)
  feature1 <- feature1[-index_sorted]
  feature2 <- feature2[-index_sorted]
  Bantu_tree3 <- drop.tip(Bantu_tree2, to_drop2)
  
  fit <- fitPagel(Bantu_tree3, x = feature1, y = feature2, model = "SYM")
  matrix_res[15,i] <- fit$P
}

matrix_res2 <- matrix_res

# making a diagonal

matrix_res[1,1] <- 1
matrix_res[2,2] <- 1
matrix_res[3,3] <- 1
matrix_res[4,4] <- 1
matrix_res[5,5] <- 1
matrix_res[6,6] <- 1
matrix_res[7,7] <- 1
matrix_res[8,8] <- 1
matrix_res[9,9] <- 1
matrix_res[10,10] <- 1
matrix_res[11,11] <- 1
matrix_res[12,12] <- 1
matrix_res[13,13] <- 1
matrix_res[14,14] <- 1
matrix_res[15,15] <- 1

write.table(file = "result_ani_based_gender_m.txt", x = matrix_res, quote = F, sep = "\t", row.names = T)


