
library(ggplot2)
library(reshape2)
library(gridExtra)

# read in the files on correlation analyses
# these were created using the other 2 scripts in this folder
result_syn <- read.csv(file = "result_syn_gender_m.txt",  sep = "\t")
result_ani_based <- read.csv(file = "result_ani_based_gender_m.txt",  sep = "\t")

# replace by categorical values for the smallest values
result_syn[result_syn < 0.00024] <- -1

# melt into long format
pre_melt <- data.frame(Var1=t(combn(colnames(result_syn),2)),Var2=result_syn[lower.tri(result_syn)])
colnames(pre_melt) <- c("Var1","Var2","value") 
melted <- melt(replace(result_syn, upper.tri(result_syn, TRUE), NA), na.rm = TRUE) # tells you "No id variables; using all as measure variables", thats OK
melted$Var2 <- as.factor(pre_melt$Var2)

# reorder the targets
levels(melted$Var2)
melted$Var2 <- factor(melted$Var2,levels(melted$Var2)[c(3,6,11,4,10,14,9,1,13,5,8,2,12,7)])

# Heatmap works, now to make it looks nice:
ggplot(data = melted, aes(variable, Var2, fill = value))+
  geom_tile(color = "white")+
  scale_fill_gradient2(low = "blue", high = "darkgray", mid = "lightgray", 
                       midpoint = 0, limit = c(-1,1), space = "Lab", 
                       name="p-value") +
  theme_minimal()+ 
  theme(axis.text.x = element_text(angle = 45, vjust = 1, 
                                   size = 12, hjust = 1))+
  coord_fixed()

#### ani-based gender

# replace by categorical values for the smallest values
result_ani_based[result_ani_based < 0.00024] <- -1

# melt into long format
ani_pre_melt <- data.frame(Var1=t(combn(colnames(result_ani_based),2)),Var2=result_ani_based[lower.tri(result_ani_based)])
colnames(ani_pre_melt) <- c("Var1","Var2","value")
ani_melted <- melt(replace(result_ani_based, upper.tri(result_ani_based, diag = T), NA), na.rm = TRUE) # tells you "No id variables; using all as measure variables", thats OK
ani_melted$Var2 <- as.factor(ani_pre_melt$Var2)

# reorder the targets
levels(ani_melted$variable)
levels(ani_melted$Var2)
ani_melted$Var2 <- factor(ani_melted$Var2,levels(ani_melted$Var2)[c(8,13,1,6,11,4,10,9,2,14,5,3,12,7)])

# Heatmap works:
ggplot(data = ani_melted, aes(variable, Var2, fill = value))+
  geom_tile(color = "white")+
  scale_fill_gradient2(low = "blue", high = "darkgray", mid = "lightgray", 
                       midpoint = 0, limit = c(-1,1), space = "Lab", 
                       name="p-value") +
  theme_minimal()+ 
  theme(axis.text.x = element_text(angle = 45, vjust = 1, 
                                   size = 12, hjust = 1))+
  coord_fixed()

#plot
plot1 <- ggplot(data = melted, aes(variable, Var2, fill = value))+
  geom_tile(color = "white")+
  scale_fill_gradient2(low = "blue", high = "darkgray", mid = "lightgray", 
                       midpoint = 0, limit = c(-1,1), space = "Lab", 
                       name="p-value") +
  theme_minimal()+ 
  theme(axis.text.x = element_text(angle = 45, vjust = 1, 
                                   size = 12, hjust = 1)) +
  theme(axis.text.y = element_text(size = 12)) +
  theme(axis.title.x = element_blank()) +
  theme(axis.title.y = element_blank()) +
  coord_fixed()

plot2 <- ggplot(data = ani_melted, aes(variable, Var2, fill = value))+
  geom_tile(color = "white")+
  scale_fill_gradient2(low = "blue", high = "darkgray", mid = "lightgray", 
                       midpoint = 0, limit = c(-1,1), space = "Lab", 
                       name="p-value") +
  theme_minimal()+ 
  theme(axis.text.x = element_text(angle = 45, vjust = 1, 
                                   size = 12, hjust = 1)) +
  theme(axis.text.y = element_text(size = 12)) +
  theme(axis.title.x = element_blank()) +
  theme(axis.title.y = element_blank()) +
  coord_fixed()

#creating the plot
cairo_pdf("two_cors_plot.pdf", family="Arial Unicode MS", 8, 16)
grid.arrange(plot1, plot2, nrow=2)
dev.off()

# the plot was manually adjusted to annotate the legend such that dark blue = 0.00024, the corrected significance level

