
library(ape)
library("caper") #comparative.data() & phylo.d()

NC_coding <- read.csv("NWB_coding_Linguistics.txt", sep = "\t", header = TRUE, stringsAsFactors=FALSE)
Bantu_tree <- read.nexus(file = "Koile_et_al_tree.nex")

# getting relevant languages only
# removing Shiwa as it doesn't fit our typology
NC_coding2 <- NC_coding[NC_coding$id != "shiw1234",]

# remove 'no data'
NC_coding3 <- NC_coding2[NC_coding2$DG_V_type != "5",]

#described in AnthroTree book:
#https://wiki.duke.edu/display/AnthroTree/5.5.1+Fritz+and+Purvis%27+D+in+R

# remove empty rows, without a tree name
NC_coding4_for_tree <- NC_coding3[NC_coding3$Koile_et_al_tree_name != "",] # 

# remove these which don't have a presence in the tree
NC_coding4_for_tree <- NC_coding4_for_tree[NC_coding4_for_tree$Koile_et_al_tree_name != "Glotto_Bafoto",]
NC_coding4_for_tree <- NC_coding4_for_tree[NC_coding4_for_tree$Koile_et_al_tree_name != "Glotto_Beeke",]
NC_coding4_for_tree <- NC_coding4_for_tree[NC_coding4_for_tree$Koile_et_al_tree_name != "D20B_Vamba_1919",]

# prune the tree
alltips <- Bantu_tree$tip.label
deltips <- NC_coding4_for_tree$Koile_et_al_tree_name
droptips <- setdiff(alltips, deltips)
pruned <- drop.tip(Bantu_tree, droptips)
pruned.lad <- ladderize(pruned, right = TRUE)

#checking tree labels to languages present
setdiff(deltips, pruned.lad$tip.label)
setdiff(pruned.lad$tip.label, deltips)

nrow(NC_coding4_for_tree)
tree_tips <- pruned.lad$tip.label
str(tree_tips)

#make a small dataframe for caper
NC_coding4_for_tree_bin_data <- NC_coding4_for_tree$Koile_et_al_tree_name
NC_coding4_for_tree_bin_data <- as.data.frame(NC_coding4_for_tree_bin_data)
NC_coding4_for_tree_bin_data$DG_V_type_binary <- NC_coding4_for_tree$DG_V_type_binary

#phylogenetic signal
com_data <- comparative.data(phy = pruned.lad, data = NC_coding4_for_tree_bin_data, names.col = NC_coding4_for_tree_bin_data, vcv = TRUE, na.omit = FALSE, warn.dropped = TRUE)

result <- phylo.d(data=com_data, binvar = DG_V_type_binary, permut = 10000)
result



