
library(ape)
library(Cairo)
library(phytools)
library(corHMM) #rayDISC()

NC_coding <- read.csv("NWB_coding_Linguistics.txt", sep = "\t", header = TRUE, na.strings = c("?", "not applicable"))
Bantu_tree <- read.nexus(file = "Koile_et_al_tree.nex")

# getting relevant languages only
# removing Shiwa as it doesn't fit our typology
NC_coding2 <- NC_coding[NC_coding$id != "shiw1234",]

# remove languages without a tree name/availability
NC_coding4_for_tree <- NC_coding2[NC_coding2$Koile_et_al_tree_name != "",] # 
NC_coding4_for_tree <- NC_coding4_for_tree[NC_coding4_for_tree$Koile_et_al_tree_name != "Glotto_Bafoto",]
NC_coding4_for_tree <- NC_coding4_for_tree[NC_coding4_for_tree$Koile_et_al_tree_name != "Glotto_Beeke",]
NC_coding4_for_tree <- NC_coding4_for_tree[NC_coding4_for_tree$Koile_et_al_tree_name != "D20B_Vamba_1919",]
NC_coding4_for_tree <- NC_coding4_for_tree[NC_coding4_for_tree$Koile_et_al_tree_name != "Glotto_Nyanga-li",]

#checking tree labels to languages present

setdiff(NC_coding4_for_tree$Koile_et_al_tree_name, Bantu_tree$tip.label)
setdiff(Bantu_tree$tip.label, NC_coding4_for_tree$Koile_et_al_tree_name)

nrow(NC_coding4_for_tree)
tree_tips <- Bantu_tree$tip.label
str(tree_tips)

# match order of languages so tiplabels doesn't screw up
match <- match(Bantu_tree$tip.label, NC_coding4_for_tree$Koile_et_al_tree_name)
NC_coding5 <- NC_coding4_for_tree[,][match,]

# for tip labels encoding 
NC_coding5_m <- matrix(ncol = 5, nrow = 248, NA)
rownames(NC_coding5_m) <- NC_coding5$tree_name

for(i in 1:nrow(NC_coding5_m)){
  if(NC_coding5$DG_V_type[i] == "1"){
    NC_coding5_m[i,1] <- 1
    NC_coding5_m[i,2] <- 0
    NC_coding5_m[i,3] <- 0
    NC_coding5_m[i,4] <- 0
    NC_coding5_m[i,5] <- 0
  }
  if(NC_coding5$DG_V_type[i] == "2"){
    NC_coding5_m[i,1] <- 0
    NC_coding5_m[i,2] <- 1
    NC_coding5_m[i,3] <- 0
    NC_coding5_m[i,4] <- 0
    NC_coding5_m[i,5] <- 0
  }
  if(NC_coding5$DG_V_type[i] == "3"){
    NC_coding5_m[i,1] <- 0
    NC_coding5_m[i,2] <- 0
    NC_coding5_m[i,3] <- 1
    NC_coding5_m[i,4] <- 0
    NC_coding5_m[i,5] <- 0
  }
  if(NC_coding5$DG_V_type[i] == "4"){
    NC_coding5_m[i,1] <- 0
    NC_coding5_m[i,2] <- 0
    NC_coding5_m[i,3] <- 0
    NC_coding5_m[i,4] <- 1
    NC_coding5_m[i,5] <- 0
  }
  if(NC_coding5$DG_V_type[i] == "5"){
    NC_coding5_m[i,1] <- 0
    NC_coding5_m[i,2] <- 0
    NC_coding5_m[i,3] <- 0
    NC_coding5_m[i,4] <- 0
    NC_coding5_m[i,5] <- 1
  }
}

#avoid too long labels
Bantu_tree$tip.label[154] <- "Glotto_Bodo_(CAR)"
Bantu_tree$tip.label[156] <- "Glotto_Boko_(DRC)"
Bantu_tree$tip.label[181] <- "Glotto_Kituba_(DRC)"
Bantu_tree$tip.label[186] <- "Glotto_Lele_(DRC)"
Bantu_tree$tip.label[208] <- "Glotto_Ngando_(CAR)"
  
# encoding for ASE and node labels
nodes_m <- matrix(ncol = 2, nrow = 248, NA)
nodes_m[,1] <- as.character(NC_coding5$Koile_et_al_tree_name)
nodes_m[,2] <- as.character(NC_coding5$DG_V_type)
nodes_m2 <- as.data.frame(nodes_m, stringsAsFactors = T)

# set root to Type 1 (ancestral Atlantic-Congo 'traditional' noun class system)
root <- c(1,0,0,0,0)

# ASE (ancestral state estimation)
num_raydisc <- rayDISC(phy = Bantu_tree, data = nodes_m2, ntraits = 1, charnum = 1, model = c("ER"), root.p = root, node.states = "marginal")

#plotting
cols <- c("black", "blue","darkorange",  "green", "darkgray")

leg <- c("syntactic agreement only", "syntactic and animacy-based agreement", "animacy-based agreement only", "no gender", "no data")

pdf("DG_V_types_on_tree.pdf", width=8, height=35)
par(mfrow=c(1,1))
plotTree(Bantu_tree, setEnv = TRUE, offset = 0.5, fsize= 1)
tiplabels(pie = NC_coding5_m, piecol = cols, cex = 0.5)
nodelabels(pie = num_raydisc$states, piecol = cols, cex = 0.6)
legend("topleft", leg, fill = cols)
dev.off()

#the pdf was adjusted further to be able to fit on a single page

# additional info on rayDISC
# from https://rdrr.io/cran/corHMM/man/rayDISC.html

### Example 1
data(rayDISC.example)
## Perform ancestral state estimation, using an asymmetric model of evolution and marginal
## reconstruction of ancestral states
recon <- rayDISC(rayDISC.example$tree,rayDISC.example$trait,model="ARD",
                 node.states="marginal")

## Plot reconstructions on tree
plotRECON(rayDISC.example$tree,recon$states)

### Example 2
## Perform ancestral state estimation on second character, using a single-rate model of
## evolution, marginal reconstruction of ancestral states, and setting the lower bound for
## parameter estimates to 0.01
recon <- rayDISC(rayDISC.example$tree,rayDISC.example$trait,charnum=2,model="ER",
                 node.states="marginal",lb=0.01)

### Example 3
## Perform ancestral state estimation on third character, using a single-rate model of
## evolution and joint reconstruction of ancestral states
recon <- rayDISC(rayDISC.example$tree,rayDISC.example$trait,charnum=3,
                 model="ER",node.states="joint")
